package com.unipi.talepis.medicalspring2021;

import org.springframework.web.bind.annotation.*;

import java.sql.*;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
public class DBController {
    private static String url = "jdbc:sqlite:src/main/resources/DB/medical2021.db";

    @RequestMapping("/allpatients")
    public String selectPatients(){
        String sql = "SELECT Patient_Name FROM Covid_Case";
        StringBuilder builder = new StringBuilder();
        try {
            Connection connection = DriverManager.getConnection(url);
            Statement statement = connection.createStatement();
            ResultSet resultSet = statement.executeQuery(sql);
            while (resultSet.next()){
                builder.append(resultSet.getString("Patient_Name")).append("<br/>");
            }
            statement.close();
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return builder.toString();
    }
    @RequestMapping("/getCases")
    public List<CovidCase> getAllCases(){
        String sql = "SELECT * FROM Covid_Case";
        List<CovidCase> covidCases = new ArrayList<>();
        try {
            Connection connection = DriverManager.getConnection(url);
            Statement statement = connection.createStatement();
            ResultSet resultSet = statement.executeQuery(sql);
            while (resultSet.next()){
                CovidCase covidCase = new CovidCase();
                covidCase.setId(resultSet.getInt("Id"));
                covidCase.setPatientName(resultSet.getString("Patient_Name"));
                covidCase.setDescription(resultSet.getString("Description"));
                covidCase.setAge(resultSet.getInt("Age"));
                covidCase.setHospital(resultSet.getString("Hospital"));
                covidCase.setGender(resultSet.getString("Gender"));
                covidCases.add(covidCase);
            }
            statement.close();
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return covidCases;
    }
    @GetMapping("/Case/{id}")
    public CovidCase getCase(@PathVariable Integer id){
        String sql = "SELECT * FROM Covid_Case WHERE Id=?";
        CovidCase covidCase = null;
        try {
            Connection connection = DriverManager.getConnection(url);
            PreparedStatement statement = connection.prepareStatement(sql);
            statement.setInt(1,id);
            ResultSet resultSet = statement.executeQuery();
            while (resultSet.next()){
                covidCase = new CovidCase();
                covidCase.setId(resultSet.getInt("Id"));
                covidCase.setPatientName(resultSet.getString("Patient_Name"));
                covidCase.setDescription(resultSet.getString("Description"));
                covidCase.setAge(resultSet.getInt("Age"));
                covidCase.setHospital(resultSet.getString("Hospital"));
                covidCase.setGender(resultSet.getString("Gender"));

            }
            statement.close();
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return covidCase;
    }
    @DeleteMapping("/Case/{id}")
    public Map<String,String> deleteCase(@PathVariable int id){
        String sql = "DELETE FROM Covid_Case WHERE Id=?";
        String message = null;
        try {
            Connection connection = DriverManager.getConnection(url);
            PreparedStatement statement = connection.prepareStatement(sql);
            statement.setInt(1,id);
            int deleted = statement.executeUpdate();
            if (deleted>0){
                message = "Deleted "+String.valueOf(deleted)+" case";
            }else {
                message = "Wrong id...";
            }
            statement.close();
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        Map<String,String> jsonMessage = new HashMap<>();
        jsonMessage.put("message",message);
        return jsonMessage;
    }
    @PostMapping("/newCase")
    public Map<String,String> insert(@RequestBody Map<String,String> body){
        int id = Integer.parseInt(body.get("id"));
        String patientName = body.get("patientName");
        String description = body.get("description");
        int age = Integer.parseInt(body.get("age"));
        String hospital = body.get("hospital");
        String gender = body.get("gender");
        String sql = "INSERT INTO Covid_Case VALUES (?,?,?,?,?,?)";
        String message = null;
        try {
            Connection connection = DriverManager.getConnection(url);
            PreparedStatement statement = connection.prepareStatement(sql);
            statement.setInt(1,id);
            statement.setString(2,patientName);
            statement.setString(3,description);
            statement.setInt(4,age);
            statement.setString(5,hospital);
            statement.setString(6,gender);
            statement.execute();
            message = "Case inserted successfully";
            statement.close();
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
            message = e.getLocalizedMessage();
        }
        Map<String,String> jsonMessage = new HashMap<>();
        jsonMessage.put("message",message);
        return jsonMessage;
    }
    @PutMapping("/updateCase/{id}")
    public Map<String,String> updateCase(@PathVariable int id, @RequestBody Map<String,String> body){
        String patientName = body.get("patientName");
        String description = body.get("description");
        int age = Integer.parseInt(body.get("age"));
        String hospital = body.get("hospital");
        String gender = body.get("gender");
        String sql = "UPDATE Covid_Case " +
                "SET Patient_Name=?," +
                "Description=?," +
                "Age=?," +
                "Hospital=?," +
                "Gender=? " +
                "WHERE Id=?";
        String message = null;
        try {
            Connection connection = DriverManager.getConnection(url);
            PreparedStatement statement = connection.prepareStatement(sql);
            statement.setString(1,patientName);
            statement.setString(2,description);
            statement.setInt(3,age);
            statement.setString(4,hospital);
            statement.setString(5,gender);
            statement.setInt(6,id);
            statement.execute();
            message = "Case updated successfully";
            statement.close();
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
            message = e.getLocalizedMessage();
        }
        Map<String,String> jsonMessage = new HashMap<>();
        jsonMessage.put("message",message);
        return jsonMessage;
    }
}
